package com.om.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.om.constant.RedisConstant;
import com.om.entity.po.Admin;
import com.om.entity.vo.AdminLoginVO;
import com.om.exception.BadReqException;
import com.om.exception.BizException;
import com.om.mapper.AdminMapper;
import com.om.service.IAdminService;
import com.om.utils.JwtUtils;
import com.om.utils.Result;
import org.apache.commons.lang3.StringUtils;
import org.springframework.data.redis.core.RedisTemplate;

import org.springframework.stereotype.Service;
import org.springframework.util.DigestUtils;

import javax.annotation.Resource;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author bmmx
 * @since 2024-01-26
 */
@Service
public class AdminServiceImpl extends ServiceImpl<AdminMapper, Admin> implements IAdminService {

    @Resource
    private JwtUtils jwtUtils;

    @Resource
    private RedisTemplate redisTemplate;


    @Override
    public Result login(String username, String password) {
        if (StringUtils.isBlank(username)){
            throw new BadReqException("用户名不能为空！");
        }
        if (StringUtils.isBlank(password)){
            throw new BadReqException("密码不能为空！");
        }

        //根据username 查询数据库
        Admin admin = this.lambdaQuery()
                .eq(Admin::getUsername, username)
                .one();
        //判断是否存在
        if (BeanUtil.isEmpty(admin)){
            throw new BadReqException("该管理员不存在！请检查用户名是否正确！");
        }
        //密码加密
         password = DigestUtils.md5DigestAsHex(password.getBytes());
        //判断密码是否正确
        if (!StringUtils.equals(password,admin.getPassword())){
            throw new BizException("密码不正确，请检查用户名和密码是否正确！");
        }

        //判断管理员状态
        if (!admin.getEnabled()){
            throw new BadReqException("该管理员已被禁用！请联系系统管理员!!!");
        }
        //封装vo返回
        AdminLoginVO adminLoginVO = BeanUtil.copyProperties(admin, AdminLoginVO.class);
        //生成token
        Map<String, Object> claims = new HashMap<>();
        claims.put("a_id",admin.getId());
        String token = jwtUtils.generateToken(claims);
        //把token存入到redis中
        String key = RedisConstant.ADMIN_TOKEN_PREFIX + admin.getId();
        redisTemplate.opsForValue().set(key,token,RedisConstant.ADMIN_TOKEN_TTL, TimeUnit.SECONDS);
        adminLoginVO.setLoginToken(token);

        return Result.ok(adminLoginVO);
    }



}
