package com.om.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.om.constant.RedisConstant;
import com.om.entity.dto.UserLoginDTO;
import com.om.entity.po.User;
import com.om.entity.vo.UserLoginVO;
import com.om.exception.BadReqException;
import com.om.mapper.UserMapper;
import com.om.service.IUserService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.om.utils.JwtUtils;
import com.om.utils.Result;
import org.apache.commons.lang3.StringUtils;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.util.DigestUtils;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * <p>
 * 应用用户信息表 服务实现类
 * </p>
 *
 * @author bmmx
 * @since 2024-01-29
 */
@Service
public class UserServiceImpl extends ServiceImpl<UserMapper, User> implements IUserService {

    @Resource
    private JwtUtils jwtUtils;

    @Resource
    private RedisTemplate redisTemplate;

    @Override
    //TODO
    public Result login(UserLoginDTO dto) {
        //从dto中获取数据
        String username = dto.getUsername();
        String password = dto.getPassword();
        String clientNum = dto.getClientNum();
        String deviceSn = dto.getDeviceSn();
        Integer type = dto.getType();

        //判断数据是否为空
        if (StringUtils.isBlank(username) || StringUtils.isBlank(password) || StringUtils.isBlank(clientNum) ||
                StringUtils.isBlank(deviceSn) || type == null){
            throw new BadReqException("数据为空！！");
        }

        //根据用户名查询用户
        User user = this.lambdaQuery()
                .eq(User::getUsername, username)
                .one();

        //判断用户是否存在
        if (BeanUtil.isEmpty(user)){
            throw new BadReqException("该用户不存在！！");
        }


        //密码加密
        password = DigestUtils.md5DigestAsHex(password.getBytes());
        //判断密码是否正确
        if (!password.equals(user.getPassword())){
            throw new BadReqException("密码错误");
        }
        // TODO 判断用户状态

        // TODO 绑定 客户端编号 和 设备 序列号  ( 判断type是登录（0）还是激活（1） )

        // 生成token
        Map<String, Object> claims = new HashMap<>();
        claims.put("u_id",user.getId());
        String token = jwtUtils.generateToken(claims);
        //把token存入到redis中
        String key = RedisConstant.USER_TOKEN_PREFIX + user.getId();
        redisTemplate.opsForValue().set(key,token,RedisConstant.USER_TOKEN_TTL, TimeUnit.SECONDS);

        //封装vo返回
        UserLoginVO userLoginVO = new UserLoginVO();
        // TODO 查询 该用户所属的 维修厂
        Integer distributorId = user.getDistributorId();//用户所属的维修厂id

        //TODO 查询用户 所绑定的vci设备

        //设置userLoginVO
        userLoginVO.setUsername(username);
        userLoginVO.setPassword(password);
        userLoginVO.setToken(token);

        return Result.ok(userLoginVO);
    }
}
